# encoding: utf-8

from __future__ import absolute_import

import cn2an.version as version
import cn2an.cn2an as cn2an
import cn2an.an2cn as an2cn


__version__ = version.VERSION
cn2an = cn2an.Cn2An().cn2an
an2cn = an2cn.An2Cn().an2cn